import { NativeLinkCommonProps, ObjectivIdProps, ObjectivLinkContextProps } from '@objectiv/tracker-react';
import React from 'react';
import { LinkProps, NavLinkProps } from 'react-router-dom';

/**
 * An overridden version of TrackedLinkProps:
 * - The objectiv props, and the object itself, are entirely optional
 * - No Component prop, as it's hard-coded to Link
 */
declare type TrackedLinkProps = LinkProps & NativeLinkCommonProps & {
    objectiv?: ObjectivIdProps & ObjectivLinkContextProps;
};
/**
 * Wraps Link in a TrackedLinkContext which automatically instruments tracking PressEvent on click.
 */
declare const TrackedLink: React.ForwardRefExoticComponent<LinkProps & Partial<Pick<HTMLElement, "id" | "title">> & {
    onClick?: React.MouseEventHandler<Element> | undefined;
} & Partial<Pick<HTMLAnchorElement, "href">> & {
    objectiv?: (ObjectivIdProps & ObjectivLinkContextProps) | undefined;
} & React.RefAttributes<HTMLAnchorElement>>;

/**
 * An overridden version of TrackedLinkProps:
 * - The objectiv props, and the object itself, are entirely optional
 * - No Component prop, as it's hard-coded to NavLink
 */
declare type TrackedNavLinkProps = NavLinkProps & NativeLinkCommonProps & {
    objectiv?: ObjectivIdProps & ObjectivLinkContextProps;
};
/**
 * Wraps NavLink in a LinkContext and automatically instruments tracking PressEvent on click.
 */
declare const TrackedNavLink: React.ForwardRefExoticComponent<NavLinkProps & Partial<Pick<HTMLElement, "id" | "title">> & {
    onClick?: React.MouseEventHandler<Element> | undefined;
} & Partial<Pick<HTMLAnchorElement, "href">> & {
    objectiv?: (ObjectivIdProps & ObjectivLinkContextProps) | undefined;
} & React.RefAttributes<HTMLAnchorElement>>;

export { TrackedLink, TrackedLinkProps, TrackedNavLink, TrackedNavLinkProps };
